/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl;

import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.CommonClassMetadata;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;

/**
 * WS common class metadata.
 * @author Guillaume Sauthier
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public class WebservicesCommonClassMetadata<
    C extends IWebservicesCommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends CommonClassMetadata<C, M, F> implements IWebservicesCommonClassMetadata<C, M, F> {

    /**
     * Set if there is a @WebService or @WebServiceProvider annotation on the class.
     */
    private IWebServiceMarker serviceMarker;

    /**
     * @return IJwsWebService object representing javax.jws.WebService annotation.
     */
    public IWebServiceMarker getWebServiceMarker() {
        return serviceMarker;
    }

    /**
     * Set IJwsWebService object.
     *
     * @param ws object representing javax.jws.WebService annotation.
     */
    public void setWebServiceMarker(final IWebServiceMarker ws) {
        this.serviceMarker = ws;
    }

}