/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.configurator;

import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonClassMetadataConfigurator;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz.JavaxJwsWebServiceVisitor;
import org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz.JavaxXmlWsWebServiceProviderVisitor;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificArchiveConfigurator;

import java.util.List;

/**
 * WebservicesCommonClassMetadataConfigurator.
 * @author Guillaume Sauthier
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class WebservicesClassMetadataConfigurator<
    C extends IWebservicesCommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends CommonClassMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param classMetadata classMetadata
     * @param specificArchiveConfiguratorList specific archive configurator list
     */
    public WebservicesClassMetadataConfigurator(final C classMetadata,
            final List<? extends ISpecificArchiveConfigurator<C, M, F>> specificArchiveConfiguratorList) {
        super(classMetadata, specificArchiveConfiguratorList);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        // Don't forget to register ancestor's visitors
        super.registerAnnotationVisitor();

        C classMetadata = getClassMetadata();


        // add @WebService
        getAnnotationVisitors().put(JavaxJwsWebServiceVisitor.TYPE,
                                    new JavaxJwsWebServiceVisitor<C>(classMetadata));

        // add @WebServiceProvider
        getAnnotationVisitors().put(JavaxXmlWsWebServiceProviderVisitor.TYPE,
                                    new JavaxXmlWsWebServiceProviderVisitor<C>(classMetadata));

    }

}
