/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.ee.metadata.ws.impl.struct.WebServiceMarker;

/**
 * This class manages the handling of &#64;{@link javax.jws.WebService} annotation.
 * @author Guillaume Sauthier
 */
public class JavaxJwsWebServiceVisitor<T extends IWebservicesCommonClassMetadata> extends AbsAnnotationVisitor<T> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/jws/WebService;";

    /**
     * The @WebService annotation representant.
     */
    private IWebServiceMarker serviceMarker;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxJwsWebServiceVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        serviceMarker = new WebServiceMarker();
    }

    /**
     * Visits a primitive value of the annotation.
     *
     * @param name  the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *              {@link Boolean}, {@link Character}, {@link Short},
     *              {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *              {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(String name, Object value) {
        if ("name".equals(name)) {
            serviceMarker.setName(name);
        }
    }

    /**
     * Visits the end of the annotation.
     */
    public void visitEnd() {
        if (serviceMarker.getName() == null) {
            // Compute default name (simple name of the class)
            String name = getAnnotationMetadata().getJClass().getName().replace('/', '.');
            int index = name.lastIndexOf(".");
            serviceMarker.setName(name.substring(index + 1));
        }
        getAnnotationMetadata().setWebServiceMarker(serviceMarker);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }
}
