/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.ws.api.interfaces.IWebService;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.ee.metadata.ws.api.IWebservicesCommonClassMetadata;
import org.ow2.util.ee.metadata.ws.impl.struct.WebServiceMarker;

/**
 * This class manages the handling of &#64;{@link javax.xml.ws.WebServiceProvider} annotation.
 * @author Guillaume Sauthier
 */
public class JavaxXmlWsWebServiceProviderVisitor<T extends IWebservicesCommonClassMetadata> extends AbsAnnotationVisitor<T> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/xml/ws/WebServiceProvider;";

    /**
     * The WS metadata representant.
     */
    private IWebServiceMarker marker;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxXmlWsWebServiceProviderVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        marker = new WebServiceMarker();
        marker.setWebServiceProvider(true);

        // Compute default port component name (FQN of the class)
        String name = annotationMetadata.getJClass().getName().replace('/', '.');
        marker.setName(name);

    }

    /**
     * Visits the end of the annotation.
     */
    public void visitEnd() {
        getAnnotationMetadata().setWebServiceMarker(marker);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }
}